pub struct BigTableConnection { /* private fields */ }Implementations
Sourceimpl BigTableConnection
impl BigTableConnection
Sourcepub async fn new(
instance_name: &str,
app_profile_id: &str,
read_only: bool,
timeout: Option<Duration>,
credential_type: CredentialType,
) -> Result<Self>
pub async fn new( instance_name: &str, app_profile_id: &str, read_only: bool, timeout: Option<Duration>, credential_type: CredentialType, ) -> Result<Self>
Establish a connection to the BigTable instance named instance_name. If read-only access
is required, the read_only flag should be used to reduce the requested OAuth2 scope.
The GOOGLE_APPLICATION_CREDENTIALS environment variable will be used to determine the program name that contains the BigTable instance in addition to access credentials.
The BIGTABLE_EMULATOR_HOST environment variable is also respected.
The BIGTABLE_PROXY environment variable is used to configure the gRPC connection through a forward proxy (see HTTP_PROXY).
Sourcepub fn client(
&self,
) -> BigTable<impl FnMut(Request<()>) -> Result<Request<()>, Status>>
pub fn client( &self, ) -> BigTable<impl FnMut(Request<()>) -> Result<Request<()>, Status>>
Create a new BigTable client.
Clients require &mut self, due to Tonic::transport::Channel limitations, however
creating new clients is cheap and thus can be used as a work around for ease of use.
pub async fn put_bincode_cells_with_retry<T>(
&self,
table: &str,
cells: &[(RowKey, T)],
overwrite: bool,
) -> Result<usize>where
T: Serialize,
pub async fn delete_rows_with_retry( &self, table: &str, row_keys: &[RowKey], ) -> Result<()>
pub async fn get_bincode_cells_with_retry<T>(
&self,
table: &str,
row_keys: &[RowKey],
) -> Result<Vec<(RowKey, Result<T>)>>where
T: DeserializeOwned,
pub async fn put_protobuf_cells_with_retry<T>(
&self,
table: &str,
cells: &[(RowKey, T)],
overwrite: bool,
) -> Result<usize>where
T: Message,